Installation
============

From PyPI
---------

The easiest way to install it is via pip from `PyPI <https://pypi.org>`_. Note that due to a name clash, on the python packaging index the package isn't called ``lymph``, but ``lymph-model``:

.. code-block:: bash

    pip install lymph-model


From Source
-----------

To install the package from the source repository, start by cloning it.

.. code-block:: bash

    git clone https://github.com/rmnldwg/lymph
    cd lymph

From here you can again use `pip <http://www.pip-installer.org/>`_ to install the local copy of the package.

.. code-block:: bash

    pip install .

.. note:: You will need to have python 3.10 or higher installed.
